Stan Math Library: stan/math/prim/mat/fun/segment.hpp File Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

Namespaces | Functions
segment.hpp File Reference
`#include <stan/math/prim/mat/fun/Eigen.hpp>`
`#include <stan/math/prim/scal/err/check_greater.hpp>`
`#include <stan/math/prim/scal/err/check_less_or_equal.hpp>`
`#include <vector>`

Go to the source code of this file.

## Namespaces
| stan
| stan::math
| Matrices and templated mathematical functions.

## Functions
template<typename T >
Eigen::Matrix< T, Eigen::Dynamic, 1 > | stan::math::segment (const Eigen::Matrix< T, Eigen::Dynamic, 1 > &v, size_t i, size_t n)
| Return the specified number of elements as a vector starting from the specified element - 1 of the specified vector. More...
template<typename T >
Eigen::Matrix< T, 1, Eigen::Dynamic > | stan::math::segment (const Eigen::Matrix< T, 1, Eigen::Dynamic > &v, size_t i, size_t n)
template<typename T >
std::vector< T > | stan::math::segment (const std::vector< T > &sv, size_t i, size_t n)

[ Stan Home Page ] © 2011–2016, Stan Development Team.